@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "scratch-plus" "1.2.0"
+(define-package "scratch-plus" "20250728.109"
   "Better Scratch Buffer Behavior."
   '((emacs "29.1"))
   :url "https://git.sr.ht/~swflint/scratch-plus"
-  :commit "cfecace1a6f3389fcabbfdd009f2b14db6dcc637"
-  :revdesc "cfecace1a6f3"
+  :commit "b794901f968000f6e338808307385b683b79ec8b"
+  :revdesc "b794901f9680"
   :keywords '("convenience")
   :authors '(("Samuel W. Flint" . "swflint@flintfam.org"))
   :maintainers '(("Samuel W. Flint" . "swflint@flintfam.org")))
