@@ -5,8 +5,8 @@
 ;; Author: Samuel W. Flint <swflint@flintfam.org>
 ;; Keywords: convenience
 ;; Homepage: https://git.sr.ht/~swflint/scratch-plus
-;; Package-Version: 1.2.0
-;; Package-Revision: cfecace1a6f3
+;; Package-Version: 20250728.109
+;; Package-Revision: b794901f9680
 ;; Package-Requires: ((emacs "29.1"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -324,7 +324,7 @@ If BUFFER is nil, operate on the current buffer."
                                       (> (buffer-size (current-buffer)) 0)
                                       (scratch-plus--buffer-scratch-p buffer)))
               (save-name (scratch-plus--save-name (buffer-local-value 'major-mode buffer)
-                                                  (when (eq is-scratch-buffer 'project-scratch)
+                                                  (when (eq is-scratch-buffer 'project)
                                                     (with-current-buffer buffer
                                                       (project-current))))))
     (with-current-buffer buffer
